@@ -59,4 +59,5 @@ benchmarkWith' cfg bm = do
   initializeTime
   withConfig cfg $ do
     _ <- note "benchmarking...\n"
-    runAndAnalyseOne 0 "function" bm
+    Analysed rpt <- runAndAnalyseOne 0 "function" bm
+    return rpt
