@@ -1,4 +1,6 @@
+{-# LANGUAGE Trustworthy #-}
 {-# LANGUAGE BangPatterns, DeriveDataTypeable, RecordWildCards #-}
+
 -- |
 -- Module      : Criterion.Analysis
 -- Copyright   : (c) 2009-2014 Bryan O'Sullivan
@@ -28,6 +30,9 @@ module Criterion.Analysis
     , regress
     ) where
 
+-- Temporary: to support pre-AMP GHC 7.8.4:
+import Data.Monoid 
+
 import Control.Arrow (second)
 import Control.Monad (unless, when)
 import Control.Monad.Reader (ask)
@@ -39,7 +44,6 @@ import Criterion.Monad (Criterion, getGen, getOverhead)
 import Criterion.Types
 import Data.Int (Int64)
 import Data.Maybe (fromJust)
-import Data.Monoid (Monoid(..))
 import Statistics.Function (sort)
 import Statistics.Quantile (weightedAvg)
 import Statistics.Regression (bootstrapRegress, olsRegress)
@@ -54,6 +58,7 @@ import qualified Data.Vector as V
 import qualified Data.Vector.Generic as G
 import qualified Data.Vector.Unboxed as U
 import qualified Statistics.Resampling.Bootstrap as B
+import Prelude
 
 -- | Classify outliers in a data set, using the boxplot technique.
 classifyOutliers :: Sample -> Outliers
