@@ -17,12 +17,15 @@ module Criterion.Monad.Internal
     , Crit(..)
     ) where
 
-import Control.Applicative (Applicative)
+-- Temporary: to support pre-AMP GHC 7.8.4:
+import Control.Applicative 
+
 import Control.Monad.Reader (MonadReader(..), ReaderT)
 import Control.Monad.Trans (MonadIO)
 import Criterion.Types (Config)
 import Data.IORef (IORef)
 import System.Random.MWC (GenIO)
+import Prelude
 
 data Crit = Crit {
     config   :: !Config
