@@ -1,3 +1,4 @@
+{-# LANGUAGE Trustworthy #-}
 {-# LANGUAGE DeriveDataTypeable, DeriveGeneric, GADTs, RecordWildCards #-}
 {-# OPTIONS_GHC -funbox-strict-fields #-}
 
@@ -63,7 +64,10 @@ module Criterion.Types
     , DataRecord(..)
     ) where
 
-import Control.Applicative ((<$>), (<*>))
+-- Temporary: to support pre-AMP GHC 7.8.4:
+import Control.Applicative
+import Data.Monoid
+
 import Control.DeepSeq (NFData(rnf))
 import Control.Exception (evaluate)
 import Data.Aeson (FromJSON(..), ToJSON(..))
@@ -71,11 +75,11 @@ import Data.Binary (Binary(..), putWord8, getWord8)
 import Data.Data (Data, Typeable)
 import Data.Int (Int64)
 import Data.Map (Map, fromList)
-import Data.Monoid (Monoid(..))
 import GHC.Generics (Generic)
 import qualified Data.Vector as V
 import qualified Data.Vector.Unboxed as U
 import qualified Statistics.Resampling.Bootstrap as B
+import Prelude
 
 -- | Control the amount of information displayed.
 data Verbosity = Quiet
@@ -108,6 +112,8 @@ data Config = Config {
       -- ^ File to write report output to, with template expanded.
     , csvFile      :: Maybe FilePath
       -- ^ File to write CSV summary to.
+    , jsonFile     :: Maybe FilePath
+      -- ^ File to write JSON-formatted results to.
     , junitFile    :: Maybe FilePath
       -- ^ File to write JUnit-compatible XML results to.
     , verbosity    :: Verbosity
@@ -171,8 +177,15 @@ data Measured = Measured {
 instance FromJSON Measured where
     parseJSON v = do
       (a,b,c,d,e,f,g,h,i,j,k) <- parseJSON v
-      return $ Measured a b c d e f g h i j k
+      -- The first four fields are not subject to the encoding policy:
+      return $ Measured a b c d
+                       (int e) (int f) (int g)
+                       (db h) (db i) (db j) (db k)
+      where int = toInt; db = toDouble
 
+-- Here we treat the numeric fields as `Maybe Int64` and `Maybe Double`
+-- and we use a specific policy for deciding when they should be Nothing,
+-- which becomes null in JSON.
 instance ToJSON Measured where
     toJSON Measured{..} = toJSON
       (measTime, measCpuTime, measCycles, measIters,
@@ -550,6 +563,7 @@ instance ToJSON Regression
 instance Binary Regression where
     put Regression{..} =
       put regResponder >> put regCoeffs >> put regRSquare
+    get = Regression <$> get <*> get <*> get
 
 instance NFData Regression where
     rnf Regression{..} =
