@@ -3,11 +3,11 @@
 
 module Properties (tests) where
 
-import Control.Applicative ((<$>))
+import Control.Applicative as A ((<$>))
 import Criterion.Analysis
 import Statistics.Types (Sample)
-import Test.Framework (Test, testGroup)
-import Test.Framework.Providers.QuickCheck2 (testProperty)
+import Test.Tasty (TestTree, testGroup)
+import Test.Tasty.QuickCheck (testProperty)
 import Test.QuickCheck
 import qualified Data.Vector.Generic as G
 import qualified Data.Vector.Unboxed as U
@@ -23,7 +23,7 @@ infixr 6 <>
 #endif
 
 instance (Arbitrary a, U.Unbox a) => Arbitrary (U.Vector a) where
-  arbitrary = U.fromList <$> arbitrary
+  arbitrary = U.fromList A.<$> arbitrary
   shrink    = map U.fromList . shrink . U.toList
 
 outlier_bucketing :: Double -> Sample -> Bool
@@ -35,7 +35,7 @@ outlier_bucketing_weighted :: Double -> Sample -> Bool
 outlier_bucketing_weighted x xs =
   outlier_bucketing x (xs <> G.replicate (G.length xs * 10) 0)
 
-tests :: Test
+tests :: TestTree
 tests = testGroup "Properties" [
     testProperty "outlier_bucketing" outlier_bucketing
   , testProperty "outlier_bucketing_weighted" outlier_bucketing_weighted
