@@ -3,8 +3,8 @@
 import Criterion.Main (bench, bgroup, env, whnf)
 import System.Environment (getEnv, withArgs)
 import System.Timeout (timeout)
-import Test.Framework (defaultMain)
-import Test.Framework.Providers.HUnit (testCase)
+import Test.Tasty (defaultMain)
+import Test.Tasty.HUnit (testCase)
 import Test.HUnit (Assertion, assertFailure)
 import qualified Criterion.Main as C
 import qualified Control.Exception as E
@@ -16,10 +16,15 @@ fib = sum . go
         go 1 = [1]
         go n = go (n-1) ++ go (n-2)
 
+-- Additional arguments to include along with the ARGS environment variable.
+extraArgs :: [String]
+extraArgs = [ "--raw=sanity.dat", "--json=sanity.json", "--csv=sanity.csv"
+            , "--output=sanity.html", "--junit=sanity.junit" ]
+
 sanity :: Assertion
 sanity = do
   args <- getArgEnv
-  withArgs args $ do
+  withArgs (extraArgs ++ args) $ do
     let tooLong = 30
     wat <- timeout (tooLong * 1000000) $
            C.defaultMain [
@@ -40,8 +45,10 @@ sanity = do
                                  show tooLong ++ " seconds!"
 
 main :: IO ()
-main = defaultMain [testCase "sanity" sanity]
+main = defaultMain $ testCase "sanity" sanity
 
+-- This is a workaround to in pass arguments that sneak past
+-- test-framework to get to criterion.
 getArgEnv :: IO [String]
 getArgEnv =
   fmap words (getEnv "ARGS") `E.catch`
